pub struct FInstance {
pub tables: HashMap<String, Vec<HashMap<String, Value>>>,
pub foreign_keys: HashMap<Edge, Vec<(usize, usize)>>,
}Expand description
A set-valued functor instance (relational data).
Tables map schema vertex IDs to rows (each row is a map of column names to values). Foreign keys map schema edges to pairs of (source row index, target row index).
Fields
tables: HashMap<String, Vec<HashMap<String, Value>>>Tables: vertex ID to rows. Each row is a column-name to value map.
foreign_keys: HashMap<Edge, Vec<(usize, usize)>>Foreign keys: edge to row-index pairs.
Implementations
Sourceimpl FInstance
impl FInstance
Sourcepub fn with_table(
self,
vertex_id: impl Into<String>,
rows: Vec<HashMap<String, Value>>,
) -> Self
pub fn with_table( self, vertex_id: impl Into<String>, rows: Vec<HashMap<String, Value>>, ) -> Self
Add a table for the given vertex.
Sourcepub fn with_foreign_key(self, edge: Edge, pairs: Vec<(usize, usize)>) -> Self
pub fn with_foreign_key(self, edge: Edge, pairs: Vec<(usize, usize)>) -> Self
Add a foreign key for the given edge.
Sourcepub fn table_count(&self) -> usize
pub fn table_count(&self) -> usize
Returns the number of tables.