pub struct WInstance {
pub nodes: HashMap<u32, Node>,
pub arcs: Vec<(u32, u32, Edge)>,
pub fans: Vec<Fan>,
pub root: u32,
pub schema_root: Name,
pub parent_map: HashMap<u32, u32>,
pub children_map: HashMap<u32, SmallVec<u32, 4>>,
}Expand description
A W-type instance: tree-shaped data conforming to a schema.
Nodes are anchored to schema vertices, connected by arcs that
correspond to schema edges. The tree is rooted at root.
Precomputed parent_map and children_map enable fast traversal.
Fields
nodes: HashMap<u32, Node>All nodes keyed by their numeric ID.
arcs: Vec<(u32, u32, Edge)>Arcs: (parent_id, child_id, schema_edge).
fans: Vec<Fan>Hyper-edge fans.
root: u32Root node ID.
schema_root: NameSchema vertex that the root node is anchored to.
parent_map: HashMap<u32, u32>Precomputed parent map: child_id -> parent_id.
children_map: HashMap<u32, SmallVec<u32, 4>>Precomputed children map: parent_id -> child IDs.
Implementations